# SDML Book Club Talk on Logic and Knowledge

## History

1736 **Königsberg Bridge Problem**: Leonhard Euler invented graph theory
1976 **Conceptual Graphs**: John F. Sowa's approach to DB inference at IBM
1982 **Knowledge Graphs**: C. Hoede, F.N. Stokman, mathematician in Netherlands
1999 **Resource Description Framework (RDF)**: W3C recommendation for Semantic Web
2001 **"The Semantic Web"**: by Tim Berners-Lee, et al. _Scientific American Magazine_
2006 **DBpedia**: linked open data from _Wikipedia_
2012 **Knowledge Graph**: Google and others
2018 **GraphQL**: open standard along side SQL, combines Cypher, PGQL and G-CORE
